@@ -24,6 +24,7 @@
 #     Harshal Mittal <harshalmittal4@gmail.com>
 #
 
+import base64
 import logging
 import json
 
@@ -61,17 +62,28 @@ class Confluence(Backend):
     :param tag: label used to mark the data
     :param archive: archive to store/retrieve items
     :param ssl_verify: enable/disable SSL verification
+    :param spaces: name of spaces to fetch, (default the entire instance)
+    :param max_contents: maximum number of contents to fetch per request
+    :param user: Confluence user name. It is required for Confluence Cloud,
+                 optional for Confluence Data Center and server editions 7.9 and later
+    :param api_token: Confluence user's personal access token or api token
     """
-    version = '0.12.0'
+    version = '0.15.0'
 
     CATEGORIES = [CATEGORY_HISTORICAL_CONTENT]
 
-    def __init__(self, url, tag=None, archive=None, ssl_verify=True):
+    def __init__(self, url, tag=None, archive=None, ssl_verify=True,
+                 spaces=None, max_contents=MAX_CONTENTS,
+                 user=None, api_token=None):
         origin = url
 
         super().__init__(origin, tag=tag, archive=archive, ssl_verify=ssl_verify)
         self.url = url
         self.client = None
+        self.spaces = spaces
+        self.max_contents = max_contents
+        self.user = user
+        self.api_token = api_token
 
     def search_fields(self, item):
         """Add search fields to an item.
@@ -104,7 +116,9 @@ class Confluence(Backend):
 
         return search_fields
 
-    def fetch(self, category=CATEGORY_HISTORICAL_CONTENT, from_date=DEFAULT_DATETIME):
+    def fetch(self, category=CATEGORY_HISTORICAL_CONTENT,
+              from_date=DEFAULT_DATETIME,
+              max_contents=MAX_CONTENTS):
         """Fetch the contents by version from the server.
 
         This method fetches the different historical versions (or
@@ -119,6 +133,7 @@ class Confluence(Backend):
         :param category: the category of items to fetch
         :param from_date: obtain historical versions of contents updated
             since this date
+        :param max_contents: maximum number of contents to fetch per request
 
         :returns: a generator of historical versions
         """
@@ -128,7 +143,8 @@ class Confluence(Backend):
         from_date = datetime_to_utc(from_date)
 
         kwargs = {
-            'from_date': from_date
+            'from_date': from_date,
+            'max_contents': max_contents
         }
 
         items = super().fetch(category, **kwargs)
@@ -144,14 +160,15 @@ class Confluence(Backend):
         :returns: a generator of items
         """
 
-        from_date = kwargs['from_date']
+        from_date = kwargs.get('from_date', DEFAULT_DATETIME)
+        max_contents = kwargs.get('max_contents', MAX_CONTENTS)
 
-        logger.info("Fetching historical contents of '%s' from %s",
-                    self.url, str(from_date))
+        logger.info("Fetching historical contents of '%s' from %s max contents per query %s",
+                    self.url, str(from_date), str(max_contents))
 
         nhcs = 0
 
-        contents = self.__fetch_contents_summary(from_date)
+        contents = self.__fetch_contents_summary(from_date, max_contents)
         contents = [content for content in contents]
 
         for content in contents:
@@ -261,11 +278,14 @@ class Confluence(Backend):
     def _init_client(self, from_archive=False):
         """Init client"""
 
-        return ConfluenceClient(self.url, archive=self.archive, from_archive=from_archive, ssl_verify=self.ssl_verify)
+        return ConfluenceClient(self.url, archive=self.archive, from_archive=from_archive,
+                                ssl_verify=self.ssl_verify, spaces=self.spaces,
+                                max_contents=self.max_contents,
+                                user=self.user, api_token=self.api_token)
 
-    def __fetch_contents_summary(self, from_date):
+    def __fetch_contents_summary(self, from_date, max_contents):
         logger.debug("Fetching contents summary from %s", str(from_date))
-        for page in self.client.contents(from_date=from_date):
+        for page in self.client.contents(from_date=from_date, max_contents=max_contents):
             for cs in self.parse_contents_summary(page):
                 yield cs
 
@@ -328,12 +348,20 @@ class ConfluenceCommand(BackendCommand):
 
         parser = BackendCommandArgumentParser(cls.BACKEND,
                                               from_date=True,
+                                              basic_auth=True,
+                                              token_auth=True,
                                               archive=True,
                                               ssl_verify=True)
 
         # Required arguments
         parser.parser.add_argument('url',
                                    help="URL of the Confluence server")
+        # Optional arguments
+        parser.parser.add_argument('--spaces', nargs='+',
+                                   help="List of spaces to fetch")
+        parser.parser.add_argument('--max-contents', dest='max_contents',
+                                   type=int, default=MAX_CONTENTS,
+                                   help="Maximum number of contents requested on the same query")
 
         return parser
 
@@ -348,6 +376,10 @@ class ConfluenceClient(HttpClient):
     :param archive: an archive to store/read fetched data
     :param from_archive: it tells whether to write/read the archive
     :param ssl_verify: enable/disable SSL verification
+    :param spaces: name of spaces to fetch, (default the entire instance)
+    :param max_contents: maximum number of contents to fetch per request
+    :param user: Confluence user name
+    :param api_token: Confluence user's personal access token or api token
     """
     URL = "%(base)s/rest/api/%(resource)s"
 
@@ -370,11 +402,32 @@ class ConfluenceClient(HttpClient):
 
     # Common values
     VCQL = "lastModified>='%(date)s' order by lastModified"
+    VCQL_SPACE = "space in (%(spaces)s) and lastModified>='%(date)s' order by lastModified"
     VEXPAND = ['body.storage', 'history', 'version']
     VHISTORICAL = 'historical'
 
-    def __init__(self, base_url, archive=None, from_archive=False, ssl_verify=True):
-        super().__init__(base_url.rstrip('/'), archive=archive, from_archive=from_archive, ssl_verify=ssl_verify)
+    def __init__(self, base_url, archive=None, from_archive=False, ssl_verify=True,
+                 spaces=None, max_contents=MAX_CONTENTS,
+                 user=None, api_token=None):
+        auth_header = {}
+        if api_token:
+            if user is None:
+                # Confluence Data Center and server editions 7.9 and later can use personal access tokens without a username
+                # See https://confluence.atlassian.com/enterprise/using-personal-access-tokens-1026032365.html
+                auth_header = {'Authorization': 'Bearer ' + api_token}
+            else:
+                # For Confluence Cloud, username and token are required
+                # See https://support.atlassian.com/atlassian-account/docs/manage-api-tokens-for-your-atlassian-account/
+                auth_encoded = base64.b64encode((user + ':' + api_token).encode('utf-8')).decode('utf-8')
+                auth_header = {'Authorization': 'Basic ' + auth_encoded}
+
+        super().__init__(base_url.rstrip('/'),
+                         archive=archive,
+                         from_archive=from_archive,
+                         ssl_verify=ssl_verify,
+                         extra_headers=auth_header)
+        self.spaces = spaces
+        self.max_contents = max_contents
 
     def contents(self, from_date=DEFAULT_DATETIME,
                  offset=None, max_contents=MAX_CONTENTS):
@@ -387,13 +440,17 @@ class ConfluenceClient(HttpClient):
 
         :param from_date: fetch the contents updated since this date
         :param offset: fetch the contents starting from this offset
-        :param limit: maximum number of contents to fetch per request
+        :param max_contents: maximum number of contents to fetch per request
         """
         resource = self.RCONTENTS + '/' + self.MSEARCH
 
         # Set confluence query parameter (cql)
         date = from_date.strftime("%Y-%m-%d %H:%M")
+
         cql = self.VCQL % {'date': date}
+        if self.spaces:
+            spaces = ", ".join(self.spaces)
+            cql = self.VCQL_SPACE % {'date': date, 'spaces': spaces}
 
         # Set parameters
         params = {
