@@ -31,9 +31,6 @@ import shutil
 import unittest
 
 import httpretty
-import pkg_resources
-
-pkg_resources.declare_namespace('perceval.backends')
 
 from perceval.backend import BackendCommandArgumentParser
 from perceval.errors import BackendError
@@ -47,6 +44,7 @@ from base import TestCaseBackendArchive
 
 BUGZILLA_SERVER_URL = 'http://example.com'
 BUGZILLA_LOGIN_URL = BUGZILLA_SERVER_URL + '/rest/login'
+BUGZILLA_VERSION_URL = BUGZILLA_SERVER_URL + '/rest/version'
 BUGZILLA_BUGS_URL = BUGZILLA_SERVER_URL + '/rest/bug'
 BUGZILLA_BUGS_COMMENTS_1273442_URL = BUGZILLA_SERVER_URL + '/rest/bug/1273442/comment'
 BUGZILLA_BUGS_HISTORY_1273442_URL = BUGZILLA_SERVER_URL + '/rest/bug/1273442/history'
@@ -74,7 +72,9 @@ def setup_http_server():
                         read_file('data/bugzilla/bugzilla_rest_bugs_attachments_empty.json', mode='rb')]
 
     def request_callback(method, uri, headers):
-        if uri.startswith(BUGZILLA_BUGS_COMMENTS_1273442_URL):
+        if uri.startswith(BUGZILLA_VERSION_URL):
+            body = '{"version":"5.1.2"}'
+        elif uri.startswith(BUGZILLA_BUGS_COMMENTS_1273442_URL):
             body = body_comments[0]
         elif uri.startswith(BUGZILLA_BUGS_HISTORY_1273442_URL):
             body = body_history[0]
@@ -94,6 +94,13 @@ def setup_http_server():
 
         return (200, headers, body)
 
+    httpretty.register_uri(httpretty.GET,
+                           BUGZILLA_VERSION_URL,
+                           responses=[
+                               httpretty.Response(body=request_callback)
+                               for _ in range(3)
+                           ])
+
     httpretty.register_uri(httpretty.GET,
                            BUGZILLA_BUGS_URL,
                            responses=[
@@ -290,6 +297,10 @@ class TestBugzillaRESTBackend(unittest.TestCase):
         httpretty.register_uri(httpretty.GET,
                                BUGZILLA_BUGS_URL,
                                body=body, status=200)
+        httpretty.register_uri(httpretty.GET,
+                               BUGZILLA_VERSION_URL,
+                               body='{"version":"5.1.2"}',
+                               status=200)
 
         bg = BugzillaREST(BUGZILLA_SERVER_URL)
         bugs = [bug for bug in bg.fetch()]
@@ -335,6 +346,10 @@ class TestBugzillaRESTBackendArchive(TestCaseBackendArchive):
         httpretty.register_uri(httpretty.GET,
                                BUGZILLA_BUGS_URL,
                                body=body, status=200)
+        httpretty.register_uri(httpretty.GET,
+                               BUGZILLA_VERSION_URL,
+                               body='{"version":"5.1.2"}',
+                               status=200)
 
         self._test_fetch_from_archive(from_date=None)
 
@@ -351,14 +366,21 @@ class TestBugzillaRESTClient(unittest.TestCase):
     def test_init(self):
         """Test initialization"""
 
+        httpretty.register_uri(httpretty.GET,
+                               BUGZILLA_VERSION_URL,
+                               body='{"version":"5.1.2"}',
+                               status=200)
+
         client = BugzillaRESTClient(BUGZILLA_SERVER_URL)
         self.assertEqual(client.base_url, BUGZILLA_SERVER_URL)
         self.assertEqual(client.api_token, None)
+        self.assertEqual(client.api_key, None)
         self.assertTrue(client.ssl_verify)
 
         client = BugzillaRESTClient(BUGZILLA_SERVER_URL, ssl_verify=False)
         self.assertEqual(client.base_url, BUGZILLA_SERVER_URL)
         self.assertEqual(client.api_token, None)
+        self.assertEqual(client.api_key, None)
         self.assertFalse(client.ssl_verify)
 
     @httpretty.activate
@@ -371,6 +393,11 @@ class TestBugzillaRESTClient(unittest.TestCase):
                                body='{"token": "786-OLaWfBisMY", "id": "786"}',
                                status=200)
 
+        httpretty.register_uri(httpretty.GET,
+                               BUGZILLA_VERSION_URL,
+                               body='{"version":"5.1.2"}',
+                               status=200)
+
         client = BugzillaRESTClient(BUGZILLA_SERVER_URL,
                                     user='jsmith@example.com',
                                     password='1234')
@@ -399,6 +426,11 @@ class TestBugzillaRESTClient(unittest.TestCase):
                                body="401 Client Error: Authorization Required",
                                status=401)
 
+        httpretty.register_uri(httpretty.GET,
+                               BUGZILLA_VERSION_URL,
+                               body='{"version":"5.1.2"}',
+                               status=200)
+
         with self.assertRaises(BackendError):
             _ = BugzillaRESTClient(BUGZILLA_SERVER_URL,
                                    user='jsmith@example.com',
@@ -421,6 +453,11 @@ class TestBugzillaRESTClient(unittest.TestCase):
                                BUGZILLA_BUGS_URL,
                                body=body, status=200)
 
+        httpretty.register_uri(httpretty.GET,
+                               BUGZILLA_VERSION_URL,
+                               body='{"version":"5.1.2"}',
+                               status=200)
+
         # Test API token login
         client = BugzillaRESTClient(BUGZILLA_SERVER_URL,
                                     user='jsmith@example.com',
@@ -459,6 +496,118 @@ class TestBugzillaRESTClient(unittest.TestCase):
         req = httpretty.last_request()
         self.assertDictEqual(req.querystring, expected)
 
+    @httpretty.activate
+    def test_bugzilla_api_key(self):
+        """Test Bugzilla API key authentication"""
+
+        # Set up a mock HTTP server
+        body = read_file('data/bugzilla/bugzilla_rest_bugs.json')
+
+        httpretty.register_uri(httpretty.GET,
+                               BUGZILLA_VERSION_URL,
+                               body='{"version":"5.1.2"}',
+                               status=200)
+        httpretty.register_uri(httpretty.GET,
+                               BUGZILLA_BUGS_URL,
+                               body=body, status=200)
+
+        # Test API token login
+        client = BugzillaRESTClient(BUGZILLA_SERVER_URL,
+                                    api_key='abcdef')
+
+        # Check whether it is included on the calls
+        _ = client.bugs()
+
+        # Check the URL containing the API key
+        req = httpretty.last_request()
+        expected_url = 'http://example.com/rest/bug?last_change_time=1970-01-01T00%3A00%3A00Z&limit=500&' \
+                       'order=changeddate&include_fields=_all&api_key=abcdef'
+        self.assertEqual(req.url, expected_url)
+
+        # Check the header that does not contain the API key
+        expected_header = "Authorization: Bearer abcdef"
+        self.assertNotIn(expected_header, req.raw_headers.decode("utf-8"))
+
+    @httpretty.activate
+    def test_bugzilla_api_key_custom_instance(self):
+        """Test Bugzilla API Key authentication on a custom instance
+        https://bugzilla.redhat.com"""
+
+        # Set up a mock HTTP server
+        body = read_file('data/bugzilla/bugzilla_rest_bugs.json')
+
+        httpretty.register_uri(httpretty.GET,
+                               BUGZILLA_VERSION_URL,
+                               body='{"code":32000,"error":true,"message":"You have attempted to access..."}',
+                               status=200)
+        httpretty.register_uri(httpretty.GET,
+                               BUGZILLA_BUGS_URL,
+                               body=body, status=200)
+
+        # Test API token login
+        client = BugzillaRESTClient(BUGZILLA_SERVER_URL,
+                                    api_key='abcdef')
+
+        self.assertEqual(client.api_key, 'abcdef')
+
+        # Check whether it is included on the calls
+        _ = client.bugs()
+
+        # Check request params
+        expected = {
+            'last_change_time': ['1970-01-01T00:00:00Z'],
+            'limit': ['500'],
+            'order': ['changeddate'],
+            'include_fields': ['_all']
+        }
+
+        req = httpretty.last_request()
+        self.assertDictEqual(req.querystring, expected)
+
+        # Check URL that does not contain the API key
+        expected_url = 'http://example.com/rest/bug?last_change_time=1970-01-01T00%3A00%3A00Z&limit=500&' \
+                       'order=changeddate&include_fields=_all'
+        self.assertEqual(req.url, expected_url)
+
+        # Check the header containing the API key
+        expected_header = "Authorization: Bearer abcdef"
+        self.assertIn(expected_header, req.raw_headers.decode("utf-8"))
+
+    @httpretty.activate
+    def test_check_bugzilla_type(self):
+        """Test Check if the type of the bugzilla is standard or custom"""
+
+        # Set up a mock HTTP server
+        httpretty.register_uri(httpretty.GET,
+                               BUGZILLA_VERSION_URL,
+                               body='{"version":"5.1.2"}',
+                               status=200)
+
+        # Test standard Bugzilla
+        client = BugzillaRESTClient(BUGZILLA_SERVER_URL, api_key='abcdef')
+        self.assertFalse(client.bugzilla_custom)
+
+        # Set up a mock HTTP server
+        httpretty.register_uri(httpretty.GET,
+                               BUGZILLA_VERSION_URL,
+                               body='{"code":32000,"error":true,"message":"You have attempted to access..."}',
+                               status=200)
+
+        # Test custom Bugzilla version https://bugzilla.redhat.com
+        client = BugzillaRESTClient(BUGZILLA_SERVER_URL, api_key='abcdef')
+        self.assertTrue(client.bugzilla_custom)
+
+        # Set up a mock HTTP server
+        body_400_error = "400 Client Error: Bad Request for url: " + BUGZILLA_VERSION_URL + "?api_key=abcdef"
+        httpretty.register_uri(httpretty.GET,
+                               BUGZILLA_VERSION_URL,
+                               body=body_400_error,
+                               status=400)
+
+        # Test custom Bugzilla version https://bugzilla.redhat.com
+        client = BugzillaRESTClient(BUGZILLA_SERVER_URL, api_key='abcdef')
+        self.assertTrue(client.bugzilla_custom)
+
     @httpretty.activate
     def test_bugs(self):
         """Test bugs API call"""
@@ -469,6 +618,11 @@ class TestBugzillaRESTClient(unittest.TestCase):
                                BUGZILLA_BUGS_URL,
                                body=body, status=200)
 
+        httpretty.register_uri(httpretty.GET,
+                               BUGZILLA_VERSION_URL,
+                               body='{"version":"5.1.2"}',
+                               status=200)
+
         # Call API
         client = BugzillaRESTClient(BUGZILLA_SERVER_URL)
         response = client.bugs()
@@ -521,6 +675,11 @@ class TestBugzillaRESTClient(unittest.TestCase):
                                BUGZILLA_BUGS_COMMENTS_1273442_URL,
                                body=body, status=200)
 
+        httpretty.register_uri(httpretty.GET,
+                               BUGZILLA_VERSION_URL,
+                               body='{"version":"5.1.2"}',
+                               status=200)
+
         # Call API
         client = BugzillaRESTClient(BUGZILLA_SERVER_URL)
         response = client.comments('1273442', '1273439')
@@ -548,6 +707,11 @@ class TestBugzillaRESTClient(unittest.TestCase):
                                BUGZILLA_BUGS_HISTORY_1273442_URL,
                                body=body, status=200)
 
+        httpretty.register_uri(httpretty.GET,
+                               BUGZILLA_VERSION_URL,
+                               body='{"version":"5.1.2"}',
+                               status=200)
+
         # Call API
         client = BugzillaRESTClient(BUGZILLA_SERVER_URL)
         response = client.history('1273442', '1273439')
@@ -575,6 +739,11 @@ class TestBugzillaRESTClient(unittest.TestCase):
                                BUGZILLA_BUGS_ATTACHMENTS_1273442_URL,
                                body=body, status=200)
 
+        httpretty.register_uri(httpretty.GET,
+                               BUGZILLA_VERSION_URL,
+                               body='{"version":"5.1.2"}',
+                               status=200)
+
         # Call API
         client = BugzillaRESTClient(BUGZILLA_SERVER_URL)
         response = client.attachments('1273442', '1273439')
@@ -603,6 +772,11 @@ class TestBugzillaRESTClient(unittest.TestCase):
                                BUGZILLA_BUGS_HISTORY_1273442_URL,
                                body=body, status=200)
 
+        httpretty.register_uri(httpretty.GET,
+                               BUGZILLA_VERSION_URL,
+                               body='{"version":"5.1.2"}',
+                               status=200)
+
         # Call API
         client = BugzillaRESTClient(BUGZILLA_SERVER_URL)
         response = client.history('1273442', '1273439')
@@ -628,6 +802,11 @@ class TestBugzillaRESTClient(unittest.TestCase):
                                BUGZILLA_BUGS_URL,
                                body=body, status=200)
 
+        httpretty.register_uri(httpretty.GET,
+                               BUGZILLA_VERSION_URL,
+                               body='{"version":"5.1.2"}',
+                               status=200)
+
         client = BugzillaRESTClient(BUGZILLA_SERVER_URL)
 
         with self.assertRaises(BugzillaRESTError) as e:
@@ -717,6 +896,13 @@ class TestBugzillaRESTCommand(unittest.TestCase):
         self.assertFalse(parsed_args.ssl_verify)
         self.assertEqual(parsed_args.url, BUGZILLA_SERVER_URL)
 
+        args = ['--api-key', 'abcdefg',
+                BUGZILLA_SERVER_URL]
+
+        parsed_args = parser.parse(*args)
+        self.assertEqual(parsed_args.api_key, 'abcdefg')
+        self.assertEqual(parsed_args.url, BUGZILLA_SERVER_URL)
+
 
 if __name__ == "__main__":
     unittest.main(warnings='ignore')
