@@ -30,7 +30,6 @@ import datetime
 import dateutil
 import httpretty
 import os
-import pkg_resources
 import unittest
 import urllib
 import unittest.mock
@@ -38,8 +37,6 @@ import unittest.mock
 from grimoirelab_toolkit.datetime import (datetime_to_utc,
                                           str_to_datetime)
 
-pkg_resources.declare_namespace('perceval.backends')
-
 from perceval.backend import BackendCommandArgumentParser
 from perceval.errors import BackendError
 from perceval.utils import DEFAULT_DATETIME
