@@ -30,15 +30,12 @@ import datetime
 import httpretty
 import json
 import os
-import pkg_resources
 import time
 import unittest
 import urllib
 
 from perceval.errors import BackendError
 
-pkg_resources.declare_namespace('perceval.backends')
-
 from perceval.backend import BackendCommandArgumentParser
 from perceval.utils import DEFAULT_DATETIME
 from perceval.backends.core.stackexchange import (StackExchange,
